@@ -72,9 +72,7 @@ class Py3status:
     button_open = 1
     button_refresh = 2
     cache_timeout = 900
-    format = (
-        r"[{name} ][[{open_issues_count}][\?soft /]" "[{open_merge_requests_count}]]"
-    )
+    format = r"[{name} ][[{open_issues_count}][\?soft /]" "[{open_merge_requests_count}]]"
     project = "gitlab-org/gitlab-ce"
     thresholds = []
 
