@@ -86,7 +86,7 @@ cycle_again
 {'full_text': 'module 3'}
 """
 
-from time import time
+import time
 
 # maximum wait for initial content at startup
 MAX_NO_CONTENT_WAIT = 5
@@ -94,8 +94,7 @@ STRING_ERROR = "missing modules"
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     align = "center"
@@ -120,7 +119,7 @@ class Py3status:
 
         self.first_run = True
         self.active = 0
-        self.cycle_time = time() + self.cycle
+        self.cycle_time = time.monotonic() + self.cycle
         self.cycle_timeout = self.cycle
         self.last_active = 0
         self.urgent = False
@@ -165,12 +164,12 @@ class Py3status:
         # and then pad with spaces to make correct width.
         current = []
         widths = []
-        for i in range(len(self.items)):
-            output = self.py3.get_output(self.items[i])
+        for i, item in enumerate(self.items):
+            output = self.py3.get_output(item)
             if not output:
                 widths.append(0)
             else:
-                widths.append(sum([len(x["full_text"]) for x in output]))
+                widths.append(sum(len(x["full_text"]) for x in output))
             if i == self.active:
                 current = output
                 current_width = widths[-1]
@@ -197,7 +196,7 @@ class Py3status:
 
     def _get_output_and_time(self):
         # get an output. again if empty (twice).
-        for x in range(3):
+        for _ in range(3):
             output = self._get_output()
             if output:
                 update_time = None
@@ -223,7 +222,7 @@ class Py3status:
             self.first_run = False
             update_time = 1
         elif self.cycle_timeout and not urgent:
-            current_time = time()
+            current_time = time.monotonic()
             if current_time >= self.cycle_time - 0.1:
                 self._change_active(1)
                 output, update_time = self._get_output_and_time()
@@ -276,7 +275,7 @@ class Py3status:
                 return
 
         self.cycle = self.cycle_timeout
-        self.cycle_time = time() + self.cycle
+        self.cycle_time = time.monotonic() + self.cycle
 
         if button == self.button_next:
             if self.open:
