@@ -8,11 +8,11 @@ as it gets.
 
 This module uses OpenWeatherMap API (https://openweathermap.org).
 
-setting `location` or `city` allows you to specify the location for the weather
-you want displaying.
+Requires a 3.0 API key for OpenWeatherMap (OWM) with a subscription which this
+module will try as hard as it can to stay under the free tier limit.
 
-Requires an API key for OpenWeatherMap (OWM), but the free tier allows you
-enough requests/sec to get accurate weather even up to the minute.
+Setting `location` or `city` allows you to specify the location for the weather
+you want displaying.
 
 I would highly suggest you install an additional font, such as the incredible
 (and free!) Weather Icons font (https://erikflowers.github.io/weather-icons),
@@ -261,12 +261,12 @@ diff
 """
 
 import datetime
-
+import json
 
 # API information
 OWM_CURR_ENDPOINT = "https://api.openweathermap.org/data/2.5/weather?"
 OWM_FUTURE_ENDPOINT = "https://api.openweathermap.org/data/2.5/forecast?"
-OWM_ONECALL_ENDPOINT = "https://api.openweathermap.org/data/2.5/onecall?"
+OWM_ONECALL_ENDPOINT = "https://api.openweathermap.org/data/3.0/onecall?exclude=alerts,minutely"
 IP_ENDPOINT = "http://geo.ultrabug.fr"
 
 # Paths of information to extract from JSON
@@ -449,6 +449,18 @@ class Py3status:
         # Generate our icon array
         self.icons = self._get_icons()
 
+        # Implement safe-to-reload rate limit
+        cached_day = datetime.datetime.now(datetime.UTC).strftime("%Y%m%d")
+        self.cached_hits = json.loads(
+            self.py3.storage_get("cached_hits") or json.dumps({cached_day: 0})
+        )
+        self.cached_onecall_response = self.py3.storage_get("cached_onecall_response")
+
+        # We want to make sure users to not exceed the request limit
+        # to 3.0 API and get billed while taking into account that
+        # OWM does refresh its API data every 10min anyway.
+        self.cache_timeout = max(600, self.cache_timeout)
+
         # Verify the units configuration
         if self.unit_rain.lower() not in RAIN_UNITS:
             raise Exception("unit_rain is not recognized")
@@ -472,9 +484,7 @@ class Py3status:
         # Initialize per-format thresholds
         self.thresholds_init = {}
         for name in ("format_humidity",):
-            self.thresholds_init[name] = self.py3.get_color_names_list(
-                getattr(self, name)
-            )
+            self.thresholds_init[name] = self.py3.get_color_names_list(getattr(self, name))
 
     def _make_req(self, url, params=None):
         # Make a request expecting a JSON response
@@ -637,12 +647,8 @@ class Py3status:
 
     def _format_wind(self, wthr):
         wind = {
-            "deg": self._jpath(
-                wthr, OWM_WIND_DEG, self._jpath(wthr, OWN_CURRENT_WIND_DEG, 0)
-            ),
-            "gust": self._jpath(
-                wthr, OWM_WIND_GUST, self._jpath(wthr, OWN_CURRENT_WIND_GUST, 0)
-            ),
+            "deg": self._jpath(wthr, OWM_WIND_DEG, self._jpath(wthr, OWN_CURRENT_WIND_DEG, 0)),
+            "gust": self._jpath(wthr, OWM_WIND_GUST, self._jpath(wthr, OWN_CURRENT_WIND_GUST, 0)),
             "speed": self._jpath(
                 wthr, OWM_WIND_SPEED, self._jpath(wthr, OWN_CURRENT_WIND_SPEED, 0)
             ),
@@ -702,9 +708,7 @@ class Py3status:
         # Format the humidity (default zero humidity)
         humidity_data = {
             "icon": self.icon_humidity,
-            "humidity": self._jpath(
-                wthr, OWM_HUMIDITY, self._jpath(wthr, OWM_CURRENT_HUMIDITY, 0)
-            ),
+            "humidity": self._jpath(wthr, OWM_HUMIDITY, self._jpath(wthr, OWM_CURRENT_HUMIDITY, 0)),
         }
 
         for x in self.thresholds_init["format_humidity"]:
@@ -717,9 +721,7 @@ class Py3status:
         # Get data and add the icon
         pressure = {
             "icon": self.icon_pressure,
-            "pressure": self._jpath(
-                wthr, OWM_PRESSURE, self._jpath(wthr, OWM_CURRENT_PRESSURE, 0)
-            ),
+            "pressure": self._jpath(wthr, OWM_PRESSURE, self._jpath(wthr, OWM_CURRENT_PRESSURE, 0)),
         }
 
         # Format the barometric pressure
@@ -728,15 +730,9 @@ class Py3status:
     def _format_temp(self, wthr):
         # Get Kelvin data (default absolute zero)
         kelvin = {
-            "day": self._jpath(
-                wthr, OWM_TEMP_DAY, self._jpath(wthr, OWM_CURRENT_TEMP, "")
-            ),
-            "max": self._jpath(
-                wthr, OWM_TEMP_MAX, self._jpath(wthr, OWM_CURRENT_TEMP_MAX, "")
-            ),
-            "min": self._jpath(
-                wthr, OWM_TEMP_MIN, self._jpath(wthr, OWM_CURRENT_TEMP_MIN, "")
-            ),
+            "day": self._jpath(wthr, OWM_TEMP_DAY, self._jpath(wthr, OWM_CURRENT_TEMP, "")),
+            "max": self._jpath(wthr, OWM_TEMP_MAX, self._jpath(wthr, OWM_CURRENT_TEMP_MAX, "")),
+            "min": self._jpath(wthr, OWM_TEMP_MIN, self._jpath(wthr, OWM_CURRENT_TEMP_MIN, "")),
         }
 
         # Temperature conversion methods
@@ -829,13 +825,14 @@ class Py3status:
 
         # Give the final format
         format_forecast_separator = self.py3.safe_format(self.format_forecast_separator)
-        today["forecast"] = self.py3.composite_join(
-            format_forecast_separator, forecasts
-        )
+        today["forecast"] = self.py3.composite_join(format_forecast_separator, forecasts)
 
         return self.py3.safe_format(self.format, today)
 
     def weather_owm(self):
+        # Prepare rate limit cache
+        cached_day = datetime.datetime.now(datetime.UTC).strftime("%Y%m%d")
+        cached_hits = self.cached_hits.get(cached_day, 0)
         # Get weather information
         loc_tz_info = self._get_loc_tz_info()
         text = ""
@@ -859,9 +856,19 @@ class Py3status:
             except Exception:
                 raise Exception("no latitude/longitude found for your config")
 
-            # onecall = forecasts
-            onecall_api_params = {"lat": lat, "lon": lon}
-            onecall = self._get_onecall(onecall_api_params)
+            # onecall = forecasts rate limited
+            if cached_hits < 999:
+                onecall_api_params = {"lat": lat, "lon": lon}
+                onecall = self._get_onecall(onecall_api_params)
+                # update and store caches
+                self.cached_onecall_response = onecall
+                self.cached_hits[cached_day] = cached_hits + 1
+                self.py3.storage_set("cached_onecall_response", onecall)
+                self.py3.storage_set(
+                    "cached_hits", json.dumps({cached_day: self.cached_hits[cached_day]})
+                )
+            else:
+                onecall = self.cached_onecall_response
             onecall_daily = onecall["daily"]
 
             fcsts_days = self.forecast_days + 1
@@ -883,12 +890,13 @@ if __name__ == "__main__":
     Run module in test mode.
     """
     from os import getenv
+
     from py3status.module_test import module_test
 
     def colorize(names, color="lightgreen", separator=None):
         if separator is None:
-            separator = "[\?color={c}&show  / ]".format(c=color)
-        body = "[\?color={c}&show {n}] [\?color={n} {{{n}}}]"
+            separator = r"[\?color={c}&show  / ]".format(c=color)
+        body = r"[\?color={c}&show {n}] [\?color={n} {{{n}}}]"
         return separator.join([body.format(c=color, n=name) for name in names])
 
     # fmt: off
@@ -903,7 +911,7 @@ if __name__ == "__main__":
         # Miscellaneous
         "api_key": getenv("OWM_API_KEY"),
         "icons": {"200": "☔", "230_232": "🌧"},
-        "format_forecast_separator": "\?color=tomato  separator ",
+        "format_forecast_separator": r"\?color=tomato  separator ",
         "forecast_days": 1,
         # Format
         "format": colorize(format_placeholders, "lightblue"),
@@ -915,9 +923,7 @@ if __name__ == "__main__":
         "format_rain": colorize(["icon", "amount", "unit"]),
         "format_snow": colorize(["icon", "amount", "unit"]),
         "format_temperature": colorize(["icon", "max", "min", "current", "unit"]),
-        "format_wind": colorize(
-            ["icon", "degree", "direction", "gust", "speed", "unit"]
-        ),
+        "format_wind": colorize(["icon", "degree", "direction", "gust", "speed", "unit"]),
     }
 
     module_test(Py3status, config)
