@@ -31,7 +31,7 @@ off
 """
 
 from os import setpgrp
-from subprocess import Popen, PIPE
+from subprocess import PIPE, Popen
 
 STRING_UNAVAILABLE = "not installed"
 
